@@ -40,6 +40,7 @@ class ANALITZA_EXPORT ExpressionParser : protected ExpressionTable
 		int errorLineNumber() const { return m_errorLineNumber; }
 		QStringList error() const { return m_err; }
 		QString mathML() const { return m_exp; }
+		QStringList comments() const { return m_comments; }
 
 	private:
 		void reallocateStack();
@@ -53,6 +54,7 @@ class ANALITZA_EXPORT ExpressionParser : protected ExpressionTable
 		int m_errorLineNumber;
 		QStringList m_err;
 		QString m_exp;
+		QStringList m_comments;
 };
 
 #endif
